aiosql package
==============

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   aiosql.adapters

Submodules
----------

aiosql.aiosql module
--------------------

.. automodule:: aiosql.aiosql
   :members:
   :undoc-members:
   :show-inheritance:

aiosql.queries module
---------------------

.. automodule:: aiosql.queries
   :members:
   :undoc-members:
   :show-inheritance:

aiosql.query\_loader module
---------------------------

.. automodule:: aiosql.query_loader
   :members:
   :undoc-members:
   :show-inheritance:

aiosql.types module
-------------------

.. automodule:: aiosql.types
   :members:
   :undoc-members:
   :show-inheritance:

aiosql.utils module
-------------------

.. automodule:: aiosql.utils
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: aiosql
   :members:
   :undoc-members:
   :show-inheritance:
